function SCDalgo_template_harness_run(obj)
% run harness and check the result

% load tunable control parameters from mds
shot = 100; % shot reference
obj.actualizeparameters(shot);

% Input Data - must be structure of timeseries matching input bus structure
time = 0:obj.gettiming.dt:1;
data = single(sin(2*pi*time*10)');
tsStructData = struct('signal',timeseries(data,time,'Name','Test Input Data'));

% SimIn object to customize configuration of Simulation run for test
SimIn = Simulink.SimulationInput(obj.getname);

% Create template Input dataset for this model
Dataset = createInputDataset(obj.getname);

% assign input data signal to Simulink.Signal object
DataIn = Simulink.SimulationData.Signal;
DataIn.Values = tsStructData;

% assign as first element in input data set
isig = find(contains(Dataset.getElementNames,'signal_in')); % find input signal index
Dataset = Dataset.setElement(isig,DataIn); %#ok<FNDSB>
SimIn.ExternalInput = Dataset; % assign this as external input for simulation

% Custom parameters for this run to save outport data
SimIn = SimIn.setModelParameter('SaveOutput','on'); % set to save outport signals
SimIn = SimIn.setModelParameter('SignalLogging','on'); % set to save log signals
SimIn = SimIn.setModelParameter('OutputSaveName','SimOut');
SimIn = SimIn.setModelParameter('SaveFormat','Dataset');
SimIn = SimIn.setModelParameter('StartTime',num2str(time(1)));
SimIn = SimIn.setModelParameter('StopTime',num2str(time(end)));
SimIn = SimIn.setModelParameter('FixedStep',num2str(mean(diff(time))));

% simulate - simulate only single types to save time
result = sim(SimIn);

% check output port data
tp = SCDalgo_template_loadtp;
output = result.SimOut{1}.Values.signal;
assert(max(output.Data) == tp.gain,'Wrong output!');

% check logs
logsout = result.logsout;
signal = logsout.getElement('signal_in').Values.signal;
assert(all(signal.Data == tsStructData.signal.Data),'Logged signal does not match input!');
end
